The HCP1065 population-averaged tractography atlas is an updated atlas from the HCP842 version. The new atlas relies on 1,065 subjects and is based on ICBM 2009a Nonlinear Asymmetric space, whereas HCP842 relied on 842 subjects and was based on FSL’s FA map (58 FA images averaged to old MNI152). The new atlas further provides subcomponents for cingulum, superior longitudinal fasciculus, corticopontine tract, corticostriatal tract, and corticothalamic tract (renamed as thalamic radiation).
Details
The included bundles are stored as objects of class fiber::bundle.
A fiber::bundle object is an S7 class which has two slots: @streamlines
and @bundle_data, where:
@streamlinesis a list of fiber::streamline objects, which, in turn, are S7 classes with slots@points,@point_dataand@streamline_data.@bundle_datais a list of metadata about the bundle, such as its name, where it was extracted from, etc.
More details about the format of the data can be found in the documentation of the fiber package.
HCP1065
A population-averaged tractography atlas based on 1,065 HCP subjects. See HCP1065 for full details, source, and references.
License
The HCP1065 data are redistributed under the Creative Commons Attribution-ShareAlike 4.0 International (CC BY-SA 4.0) license, as specified by the original DSI Studio / Fiber Data Hub release. See https://creativecommons.org/licenses/by-sa/4.0/.
HCP Data Terms
The atlas is derived from the Human Connectome Project Young Adult dataset. Users must comply with the applicable HCP data-use terms and acknowledgment requirements.
Modifications
The original .trk streamline files from the DSI Studio / Fiber Data Hub
release have been converted to R fiber::bundle objects and serialised as
.rds files. No spatial or statistical modifications were made to the
streamline data. All 87 bundles are hosted together in the single
hcp1065 GitHub release of this repository.
References
Yeh, Fang-Cheng, et al. "Population-averaged atlas of the macroscale human structural connectome and its network topology." Neuroimage 178 (2018): 57-68. https://doi.org/10.1016/j.neuroimage.2018.05.027
Yeh, Fang-Cheng. "Population-based tract-to-region connectome of the human brain and its hierarchical topology." Nature communications 13.1 (2022): 4933. https://doi.org/10.1038/s41467-022-32595-4
Yeh, Fang-Cheng. "DSI Studio: an integrated tractography platform and fiber data hub for accelerating brain research." Nature methods 22.8 (2025): 1617-1619. https://doi.org/10.1038/s41592-025-02762-8